==> drools-quarkus-unit-example-0.4.0-sources.jar: org/kie/kogito/queries/AdultUnitRuleUnit.java <==
package org.kie.kogito.queries;

import org.drools.core.RuleBaseConfiguration;
import org.drools.core.SessionConfigurationImpl;
import org.drools.core.impl.EnvironmentImpl;
import org.kie.api.KieBaseConfiguration;
import org.kie.api.runtime.KieSession;

@javax.inject.Singleton()
public class AdultUnitRuleUnit extends org.kie.kogito.rules.impl.AbstractRuleUnit<AdultUnit> {

    public AdultUnitRuleUnit() {
        this(new org.kie.kogito.examples.Application());
    }

    @javax.inject.Inject()
    public AdultUnitRuleUnit(org.kie.kogito.Application app) {
        super(app);
    }

    public org.kie.kogito.queries.AdultUnitRuleUnitInstance createInstance(AdultUnit value) {
        return new org.kie.kogito.queries.AdultUnitRuleUnitInstance(this, value, createLegacySession());
    }

    private org.kie.api.runtime.KieSession createLegacySession() {
        if (app.config() != null && app.config().rule() != null) {
            org.kie.kogito.rules.RuleConfig ruleCfg = app.config().rule();
            KieBaseConfiguration kieBaseConfiguration = new RuleBaseConfiguration();
            kieBaseConfiguration.setOption(ruleCfg.eventProcessingMode());
            org.drools.core.impl.InternalKnowledgeBase kb = org.drools.modelcompiler.builder.KieBaseBuilder.createKieBaseFromModel(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit(), kieBaseConfiguration);
            SessionConfigurationImpl sessionConfiguration = new SessionConfigurationImpl();
            sessionConfiguration.setOption(ruleCfg.clockType());
            KieSession ks = kb.newKieSession(sessionConfiguration, new EnvironmentImpl());
            org.kie.kogito.rules.RuleEventListenerConfig ruleEventListenerConfig = ruleCfg.ruleEventListeners();
            ruleEventListenerConfig.agendaListeners().forEach(ks::addEventListener);
            ruleEventListenerConfig.ruleRuntimeListeners().forEach(ks::addEventListener);
            return ks;
        } else {
            return org.drools.modelcompiler.builder.KieBaseBuilder.createKieBaseFromModel(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit()).newKieSession();
        }
    }
}

==> drools-quarkus-unit-example-0.5.0-sources.jar: org/kie/kogito/queries/AdultUnitRuleUnit.java <==
package org.kie.kogito.queries;

import org.drools.core.RuleBaseConfiguration;
import org.drools.core.SessionConfigurationImpl;
import org.drools.core.impl.EnvironmentImpl;
import org.drools.core.impl.InternalKnowledgeBase;
import org.drools.modelcompiler.builder.KieBaseBuilder;
import org.kie.api.KieBaseConfiguration;
import org.kie.api.runtime.KieSession;

@javax.inject.Singleton()
public class AdultUnitRuleUnit extends org.kie.kogito.rules.impl.AbstractRuleUnit<AdultUnit> {

    private final InternalKnowledgeBase kbase;

    public AdultUnitRuleUnit() {
        this(new org.kie.kogito.examples.Application());
    }

    @javax.inject.Inject()
    public AdultUnitRuleUnit(org.kie.kogito.Application app) {
        super(app);
        this.kbase = createKieBase();
    }

    public org.kie.kogito.queries.AdultUnitRuleUnitInstance createInstance(AdultUnit value) {
        return new org.kie.kogito.queries.AdultUnitRuleUnitInstance(this, value, createLegacySession());
    }

    private InternalKnowledgeBase createKieBase() {
        if (app.config() != null && app.config().rule() != null) {
            org.kie.kogito.rules.RuleConfig ruleCfg = app.config().rule();
            KieBaseConfiguration kieBaseConfiguration = new RuleBaseConfiguration();
            kieBaseConfiguration.setOption(ruleCfg.eventProcessingMode());
            return KieBaseBuilder.createKieBaseFromModel(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit(), kieBaseConfiguration);
        } else {
            return KieBaseBuilder.createKieBaseFromModel(new org.kie.kogito.queries.RulesF894883E1030542FEFCE9860F835B9B7_AdultUnit());
        }
    }

    private org.kie.api.runtime.KieSession createLegacySession() {
        if (app.config() != null && app.config().rule() != null) {
            org.kie.kogito.rules.RuleConfig ruleCfg = app.config().rule();
            SessionConfigurationImpl sessionConfiguration = new SessionConfigurationImpl();
            sessionConfiguration.setOption(ruleCfg.clockType());
            KieSession ks = kbase.newKieSession(sessionConfiguration, new EnvironmentImpl());
            org.kie.kogito.rules.RuleEventListenerConfig ruleEventListenerConfig = ruleCfg.ruleEventListeners();
            ruleEventListenerConfig.agendaListeners().forEach(ks::addEventListener);
            ruleEventListenerConfig.ruleRuntimeListeners().forEach(ks::addEventListener);
            return ks;
        } else {
            return kbase.newKieSession();
        }
    }
}
